import 'reflect-metadata';
import { ValidationError } from 'class-validator';
import { EFieldTypes, ESelectTypes, ICrossFieldValidationRule, ICrossFieldValidations, IJsonSchema, IOption, IProperty, IRegularBreakpoints } from './modelsCommon';
import { ICrossFieldConditions, IFormLayout, IFormOverrides, IFormV2Full } from './models';
import { IChildrenArrayFull, IChildrenAutoCompleteFull, IChildrenCheckboxFull, IChildrenDateFull, IChildrenDateRangeFull, IChildrenEmptyFull, IChildrenFileFull, IChildrenMobilePhoneFull, IChildrenMultipleAutocompleteFull, IChildrenNumberFull, IChildrenRadioButtonFull, IChildrenRadioButtonMatrixFull, IChildrenAssessmentFull, IChildrenSwitchFull, IChildrenTextFull, IChildrenYesNoRadioButtonFull, ICommonChildrenFull, IFormGroupFull, IRadioButtonMatrixOptions } from './inputsModels';
export declare let validProperties: string[];
export declare class Option<T> implements IOption<T> {
    id: number;
    label: string;
    value: T;
}
declare class JsonSchema implements IJsonSchema {
    $schema: string;
    title: string;
    description: string;
    type: string;
    properties: IProperty;
    required: Array<string>;
}
export declare class CrossFieldValidationRule implements ICrossFieldValidationRule {
    errorKey: string;
    testCondition: string;
    meta?: {
        param: number;
    };
    constructor(obj: ICrossFieldValidationRule);
}
export declare class CommonChildrenFull implements ICommonChildrenFull {
    type: EFieldTypes;
    fieldName: string;
    initialValue: string | null | boolean | number | false | [null, null];
    templateId: string;
    fieldTitle?: string;
    fieldSubtitle?: string;
}
export declare class ChildrenTextFull extends CommonChildrenFull implements IChildrenTextFull {
    multiline?: boolean;
    maxLength?: string;
    type: EFieldTypes.TEXT;
    placeholder?: string;
    initialValue: null;
    disabled?: boolean | undefined;
}
export declare class ChildrenAutoCompleteFull extends CommonChildrenFull implements IChildrenAutoCompleteFull {
    backendOptions?: boolean;
    backendSelectType?: ESelectTypes;
    options: IOption<any>[];
    disabledOptionIds?: number[];
    type: EFieldTypes.AUTOCOMPLETE;
    initialValue: null;
    loading?: boolean | undefined;
    placeholder?: string;
    disabled?: boolean | undefined;
}
declare class ChildrenMobilePhoneFull extends CommonChildrenFull implements IChildrenMobilePhoneFull {
    type: EFieldTypes.MOBILE_PHONE;
    initialValue: string;
    placeholder?: string;
    maxLength?: string;
}
declare class ChildrenRadioButtonFull extends CommonChildrenFull implements IChildrenRadioButtonFull {
    type: EFieldTypes.RADIOBUTTON;
    initialValue: null;
    options: IOption<any>[];
}
declare class ChildrenCheckboxFull extends CommonChildrenFull implements IChildrenCheckboxFull {
    label: string;
    disabled?: boolean | undefined;
    type: EFieldTypes.CHECKBOX;
    initialValue: boolean;
}
declare class ChildrenNumberFul extends CommonChildrenFull implements IChildrenNumberFull {
    type: EFieldTypes.NUMBER;
    initialValue: number;
}
export declare class ChildrenDateFull extends CommonChildrenFull implements IChildrenDateFull {
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
    type: EFieldTypes.DATE;
    initialValue: null;
}
declare class ChildrenDateRangeFull extends CommonChildrenFull implements IChildrenDateRangeFull {
    type: EFieldTypes.DATE_RANGE;
    initialValue: [null, null];
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
}
declare class ChildrenFileFull extends CommonChildrenFull implements IChildrenFileFull {
    type: EFieldTypes.FILE;
}
declare class ChildrenMultipleAutocompleteFull extends CommonChildrenFull implements IChildrenMultipleAutocompleteFull {
    type: EFieldTypes.MULTIPLE_AUTOCOMPLETE;
}
declare class ChildrenArrayFull extends CommonChildrenFull implements IChildrenArrayFull {
    type: EFieldTypes.ARRAY;
}
declare class RadioButtonMatrixOptions implements IRadioButtonMatrixOptions {
    rows: IOption<any>[];
    columns: IOption<any>[];
    grid?: IRegularBreakpoints;
}
declare class ChildrenRadioButtonMatrixFull extends CommonChildrenFull implements IChildrenRadioButtonMatrixFull {
    type: EFieldTypes.RADIOBUTTON_MATRIX;
    radioButtonMatrixOptions: RadioButtonMatrixOptions;
}
declare class ChildrenEmptyFull extends CommonChildrenFull implements IChildrenEmptyFull {
    type: EFieldTypes.EMPTY;
}
declare class ChildrenSwitchFull extends CommonChildrenFull implements IChildrenSwitchFull {
    type: EFieldTypes.SWITCH;
}
declare class ChildrenYesNoRadioButtonFull extends CommonChildrenFull implements IChildrenYesNoRadioButtonFull {
    type: EFieldTypes.YES_NO_RADIOBUTTON;
    options: IOption<boolean>[];
    initialValue: null;
}
declare class ChildrenAssessmentFull extends CommonChildrenFull implements IChildrenAssessmentFull {
    type: EFieldTypes.ASSESSMENT;
    assessments: {
        [key: number]: string;
    };
}
export declare class FormGroupFull implements IFormGroupFull {
    id: string;
    title?: string;
    subtitle?: string;
    children: Array<ChildrenTextFull | ChildrenAutoCompleteFull | ChildrenDateFull | ChildrenRadioButtonFull | ChildrenCheckboxFull | ChildrenNumberFul | ChildrenMobilePhoneFull | ChildrenDateRangeFull | ChildrenFileFull | ChildrenMultipleAutocompleteFull | ChildrenArrayFull | ChildrenRadioButtonMatrixFull | ChildrenEmptyFull | ChildrenSwitchFull | ChildrenYesNoRadioButtonFull | ChildrenAssessmentFull>;
}
export declare class FormV2Full implements IFormV2Full {
    formatVersion: 2;
    validationObject: JsonSchema;
    crossFieldValidations: ICrossFieldValidations;
    crossFieldConditions: ICrossFieldConditions;
    overrides: IFormOverrides;
    formLayout: IFormLayout;
    children: Array<FormGroupFull | ChildrenTextFull | ChildrenAutoCompleteFull | ChildrenDateFull | ChildrenRadioButtonFull | ChildrenCheckboxFull | ChildrenNumberFul | ChildrenMobilePhoneFull | ChildrenDateRangeFull | ChildrenFileFull | ChildrenMultipleAutocompleteFull | ChildrenArrayFull | ChildrenRadioButtonMatrixFull | ChildrenEmptyFull | ChildrenSwitchFull | ChildrenYesNoRadioButtonFull | ChildrenAssessmentFull>;
    submitButtonText: string;
    cancelButtonText?: string;
}
export declare const validateSchema: (form: FormV2Full) => Promise<ValidationError[]>;
export {};
