import { ValidationArguments, ValidationOptions, registerDecorator } from 'class-validator';

export function IsAssessments(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isAssessments',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any) {
          if (typeof value !== 'object') {
            return false;
          }
          for (const key in value) {
            if (!Number.isInteger(Number(key))) {
              return false;
            }
            if (typeof value[key] !== 'string') {
              return false;
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be a valid assessments object.`;
        },
      },
    });
  };
}
