export enum EFieldTypes {
  TEXT = 'text',
  NUMBER = 'number',
  SWITCH = 'switch',
  DATE = 'date',
  DATE_RANGE = 'dateRange',
  AUTOCOMPLETE = 'autoComplete',
  FILE = 'file',
  ARRAY = 'array',
  MOBILE_PHONE = 'mobilePhone',
  MULTIPLE_AUTOCOMPLETE = 'autoCompleteMultiple',
  RADIOBUTTON = 'radioButton',
  YES_NO_RADIOBUTTON = 'yesNoRadioButton',
  EMPTY = 'empty',
  CHECKBOX = 'checkbox',
  RADIOBUTTON_MATRIX = 'radioButtonMatrix',
  ASSESSMENT ="assessment"
}

export type GridSize = 1 | 2 | 3 | 4 | 6 | 8 | 10 | 12 | 'auto';

export interface IRegularBreakpoints {
  lg?: GridSize;
  md?: GridSize;
  sm?: GridSize;
  xl?: GridSize;
  xs?: GridSize;
}

export interface IOption<T> {
  id: number;
  label: string;
  value: T;
}

export enum ESelectTypes {
  COUNTRIES = 'countries',
  RELATIONSHIP = 'relationship',
}

// ------------------------------ BASE FORM CHILDREN INTERFACES ------------------------------ //
export interface IFormFieldBase {
  type: EFieldTypes;
  fieldName: string;
  initialValue?: any;
  templateId?: string;
}

export interface IFormGroupBase {
  title?: string;
  subtitle?: string;
  children: Array<IFormFieldBase>;
}

// ------------------------------ CROSS FIELD CONDITIONS INTERFACES ------------------------------ //
export type ICrossFieldConditionsParams = {
  required?: string;
  disabled?: string;
  renderCondition?: string;
  disabledCondition?: string;
};

// ------------------------------ CROSS FIELD VALIDATION INTERFACES ------------------------------ //
export interface ICrossFieldValidationRule {
  errorKey: string;
  testCondition: string;
  meta?: { param: number };
}

export interface IFormSettingsOverrides {
  disablePast?: boolean
  disableFuture?: boolean;
  disabled?: boolean;
  backendSelectType?: ESelectTypes;
  fieldTitle?: string;
  fieldSubtitle?: string | null;
  initialValue?: any;
  options?: IOption<any>[];
  placeholder?: string;
  helperText?: string;
}

export type ICrossFieldValidations = {
  [key in string]?: ICrossFieldValidationRule[];
};

// ------------------------------ JSON SCHEMA INTERFACES ------------------------------ //
// JSON schema property describes validation for each field in the form
export type IJsonSchemaProperty = {
  id: number;
  type: 'string' | 'boolean' | 'array' | 'number';
  nullable?: boolean;
  maxLength?: number;
  minLength?: number;
  pattern?: string;
  oneOf?: Array<string | boolean | null>;
  items?: {
    type: 'string';
    format: 'date';
    minLength: number;
    required: boolean;
  };
};

export type IProperty = {
  [key in string]: IJsonSchemaProperty;
};

// JSON schema interface https://json-schema.org/learn/getting-started-step-by-step
export interface IJsonSchema {
  $schema: string;
  title: string;
  description: string;
  type: string;
  properties: IProperty;
  required: Array<string>;
}

// ------------------------------ OUTPUTS ------------------------------ //
// Validation error DTO interface
export interface IValidationError {
  translationKey: string;
  fallbackLanguageTranslation: string;
  meta: {
    [key: string]: any;
  };
}

// Validation error field DTO interface
export interface IValidationErrorField{
  property: string;
  constraints: {
    [key: string]: IValidationError;
  };
}

// Form validation errors DTO interface
export type IValidationErrors = {
  [key in string]?: IValidationErrorField;
};
